@@ -11,6 +11,7 @@ from gateways.apis.api_cost import ApiCost
 from gateways.apis.api_debugging import ApiDebugging
 from gateways.apis.api_oauth_redirect import ApiOauthRedirect
 from gateways.apis.api_parameter_store import ParameterStore
+from gateways.apis.api_policy import ApiPolicy
 from gateways.apis.api_production import ApiProduction
 from gateways.apis.api_qualiy import ApiQualiY
 from gateways.apis.api_sandbox import ApiSandbox
@@ -40,3 +41,4 @@ class ApiRoot:
         self.cost = ApiCost(api_address, version)
         self.debugging = ApiDebugging(api_address, version)
         self.parameterStore = ParameterStore(api_address, version)
+        self.policy = ApiPolicy(api_address, version)
