@@ -5,8 +5,6 @@ import abc
 from typing import List, Optional
 import dateutil.parser
 
-from common.assertion_helper import AssertionHelper
-
 
 class AccessLink:
     def __init__(self, protocol: str, link: str):
@@ -156,32 +154,6 @@ class TerraformModuleDescriptor:
         self.outputs = outputs
         self.inputs = inputs
 
-    def __eq__(self, other):
-        if not isinstance(other, TerraformModuleDescriptor):
-            return NotImplemented
-
-        name = self.name == other.name
-        module_repo_name = self.module_repo_name == other.module_repo_name
-        module_root_path = self.module_root_path == other.module_root_path
-        description = self.description == other.description
-        terraform_version = self.terraform_version == other.terraform_version
-        enable_auto_tagging = self.enable_auto_tagging == other.enable_auto_tagging
-        exclude_from_tagging = AssertionHelper.compare_arrays(self.exclude_from_tagging, other.exclude_from_tagging)
-        allowed_spaces = AssertionHelper.compare_arrays(self.allowed_spaces, other.allowed_spaces)
-
-        current_cs = \
-            sorted(self.compute_services, key=lambda x: x.cloud_account_name + x.compute_service_name, reverse=True)
-        other_cs = \
-            sorted(other.compute_services, key=lambda x: x.cloud_account_name + x.compute_service_name, reverse=True)
-        compute_services = current_cs == other_cs
-
-        outputs = self.outputs == other.outputs
-        inputs = self.inputs == other.inputs
-
-        return name and module_repo_name and module_root_path and description and terraform_version and \
-               enable_auto_tagging and exclude_from_tagging and allowed_spaces and compute_services and \
-               outputs and inputs
-
 
 class SpaceHelmChartComputeService:
     def __init__(self, cloud_account_name: str, compute_service_name: str, service_account_name: Optional[str] = None):
@@ -257,22 +229,3 @@ class HelmChartDescriptor:
         self.outputs = outputs
         self.inputs = inputs
         self.commands = commands
-
-    def __eq__(self, other):
-        if not isinstance(other, HelmChartDescriptor):
-            return NotImplemented
-
-        name = self.name == other.name
-        chart_root_path = self.chart_root_path == other.chart_root_path
-        description = self.description == other.description
-        enable_logs = self.enable_logs == other.enable_logs
-        perform_helm_test = self.perform_helm_test == other.perform_helm_test
-        override_values_yaml = self.override_values_yaml == other.override_values_yaml
-        compute_service = self.compute_service == other.compute_service
-        outputs = AssertionHelper.compare_arrays(self.outputs, other.outputs)
-        inputs = AssertionHelper.compare_arrays(self.inputs, other.inputs)
-        commands = AssertionHelper.compare_arrays(self.commands, other.commands)
-
-        return name and chart_root_path and description and enable_logs and perform_helm_test and compute_service and \
-            compute_service and compute_service and override_values_yaml and \
-            outputs and inputs and commands
