@@ -1004,9 +1004,8 @@ class Converters:
                 name=service["name"],
                 status=service["status"],
                 service_type=service["type"],
-                # TODO: helm: fix it
-                progress=Converters._create_tf_progress_response(service.get("progress", None)),
-                logs=Converters._create_tf_logs_response(service.get("logs", None))
+                progress=Converters._create_tf_progress_response(service["progress"]),
+                logs=Converters._create_tf_logs_response(service["logs"])
             )
         elif service["type"] == ServiceType.Helm:
             return HelmServiceResponse(
